/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

/**
 */
public class FileChooserException extends Exception {
    private int errorCode = 0;

    FileChooserException(int errorCode) {
        this.errorCode = errorCode;
    }

    private FileChooserException() {
    }

    public FileChooserError getError() {
        return FileChooserError.intern(errorCode);
    }
}
